==> digikam-3.0.0-rc.tar.bz2: digikam-3.0.0-rc/extra/kipi-plugins/metadataedit/plugin/kipiplugin_metadataedit.desktop.cmake <==
[Desktop Entry]
Comment=A tool to edit EXIF, IPTC and XMP metadata
Comment[ast]=Una ferramienta pa editar EXIF, IPTC y metadatos XMP
Comment[bg]=Инструмент за редактиране на метаданни EXIF, IPTC и XMP
Comment[ca]=Una eina per a editar metadades EXIF, IPTC i XMP
Comment[ca@valencia]=Una eina per a editar metadades EXIF, IPTC i XMP
Comment[cs]=Nástroj pro úpravu metadat EXIF, IPTC a XMP
Comment[da]=Et værktøj til at redigere EXIF-, IPTC- og XMP-metadata
Comment[de]=Ein Werkzeug, um EXIF-, IPTC- und XMP-Metadaten zu bearbeiten.
Comment[el]=Εργαλείο επεξεργασίας μεταδεδομένων EXIF, IPTC και XMP
Comment[en_GB]=A tool to edit EXIF, IPTC and XMP metadata
Comment[es]=Una herramienta para editar los metadatos EXIF, IPTC y XMP.
Comment[et]=Tööriist EXIF-i, IPTC ja XMP metaandmete muutmiseks
Comment[eu]=EXIF, IPTC eta XMP metadatuak editatzeko tresna
Comment[fi]=Exif, iptc ja xmp-metatietojen muokkaus
Comment[fr]=Outil pour l'édition les métadonnées EXIF, IPTC et XMP
Comment[ga]=Uirlis lenar féidir meiteashonraí EXIF, IPTC, agus XMP a chur in eagar
Comment[gl]=Unha ferramenta para editar metadatos EXIF, IPTC e XMP
Comment[he]=כלי לעריכת מידע EXIF,‏ IPTC ו-XMP
Comment[hne]=एक्सिफ, आईपीटीसी अउ एक्सएमपी मेटाडाटा ल संपादित करे के एक औजार
Comment[hu]=Egy eszköz EXIF, IPTC és XMP metaadat szerkesztéséhez
Comment[is]=Verkfæri til að eiga við EXIF, IPTC og XMP lýsigögn
Comment[it]=Uno strumento per modificare i dati aggiuntivi EXIF, IPTC e XMP
Comment[ja]=Exif, IPTC, XMP メタデータを編集するツール
Comment[km]=ឧបករណ៍​ត្រូវ​កែសម្រួល EXIF, IPTC និង​ទិន្នន័យ​មេតា XMP
Comment[lv]=Rīks EXIF, IPTC un XMP metadatu rediģēšanai
Comment[nb]=Et verktøy for å redigere EXIF-, IPIC- og XMP-metadata
Comment[nds]=En Warktüüch, mit dat sik EXIF-, IPTC- un XMP-Metadaten bewerken laat
Comment[nl]=Een hulpmiddel voor het bewerken van EXIF-, IPTC- en XMP-metadata
Comment[pa]=EXIF, IPTC ਅਤੇ XMP ਮੇਟਾਡਾਟਾ ਸੋਧਣ ਲਈ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do edycji meta-danych EXIF, IPTC i XMP
Comment[pt]=Uma ferramenta para editar meta-dados EXIF, IPTC e XMP
Comment[pt_BR]=Uma ferramenta para editar metadados EXIF, IPTC e XMP
Comment[ro]=O unealtă de editat metadatele EXIF, IPTC și XMP
Comment[ru]=Инструмент для редактирования метаданных EXIF, IPTC и XMP
Comment[sk]=Nástroj na úpravu EXIF, IPTC a XMP metadát
Comment[sl]=Orodje za urejanja metapodatkov EXIF, IPTC in XMP
Comment[sq]=Një mjet për të modifikuar EXIF, IPTC dhe XMP metadata
Comment[sv]=Ett verktyg för att redigera EXIF-, IPTC- och XMP-metadata
Comment[th]=เครื่องมือแก้ไขข้อมูลกำกับภาพแบบ EXIF, IPTC และ XMP
Comment[tr]=EXIF, IPTC ve XMP üstverilerini düzenlemek için bir araç
Comment[uk]=Інструмент для редагування метаданих EXIF, IPTC і XMP
Comment[x-test]=xxA tool to edit EXIF, IPTC and XMP metadataxx
Comment[zh_CN]=一个编辑 EXIF、IPTC 和 XMP 元数据的工具
Comment[zh_TW]=編輯 EXIF、IPTC 和 XMP 中繼資料
Icon=metadataedit
Name=MetadataEdit
Name[ast]=MetadataEdit
Name[bg]=Редактиране на метаданни
Name[ca]=MetadataEdit
Name[ca@valencia]=MetadataEdit
Name[cs]=MetadataEdit
Name[da]=MetadataEdit
Name[de]=Metadaten-Editor
Name[el]=MetadataEdit
Name[en_GB]=MetadataEdit
Name[es]=Editar metadatos
Name[et]=Metaandmete redaktor
Name[eu]=Metadatuen editorea
Name[fi]=Metadata-editori
Name[fr]=SendImages
Name[ga]=MetadataEdit
Name[gl]=MetadataEdit
Name[he]=עריכת Metadata
Name[hne]=मेटाडाटा-एडिट
Name[hu]=Metaadat szerkesztő
Name[is]=MetadataEdit
Name[it]=Modifica dei dati aggiuntivi
Name[ja]=MetadataEdit
Name[km]=កែសម្រួល​ទិន្នន័យ​មេតា
Name[ko]=MetadataEdit
Name[lv]=Metadatu redaktors
Name[nb]=MetadataEdit
Name[nds]=Metadaten bewerken
Name[nl]=MetadataEdit
Name[pa]=MetadataEdit
Name[pl]=EdycjaMeta-danych
Name[pt]=Editor de Meta-Dados
Name[pt_BR]=Editor de metadados
Name[ro]=Editare metadate
Name[ru]=Редактирование метаданных
Name[sk]=Úprava metadát
Name[sl]=MetadataEdit
Name[sq]=MetadataEdit
Name[sv]=Metadataeditor
Name[th]=แก้ไขข้อมูลของภาพ
Name[tr]=Metadata Düzenle
Name[uk]=MetadataEdit
Name[x-test]=xxMetadataEditxx
Name[zh_CN]=元数据编辑
Name[zh_TW]=中繼資料編輯
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_metadataedit
X-KIPI-PluginCategories=Image
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com

==> digikam_3.5.0.orig.tar.bz2: digikam-3.5.0/extra/kipi-plugins/metadataedit/plugin/kipiplugin_metadataedit.desktop.cmake <==
[Desktop Entry]
Comment=A tool to edit EXIF, IPTC and XMP metadata
Comment[ast]=Una ferramienta pa editar EXIF, IPTC y metadatos XMP
Comment[bg]=Инструмент за редактиране на метаданни EXIF, IPTC и XMP
Comment[bs]=Alat za obradu EXIF, IPTC i XMP meta podataka
Comment[ca]=Una eina per a editar metadades EXIF, IPTC i XMP
Comment[ca@valencia]=Una eina per a editar metadades EXIF, IPTC i XMP
Comment[cs]=Nástroj pro úpravu metadat EXIF, IPTC a XMP
Comment[da]=Et værktøj til at redigere EXIF-, IPTC- og XMP-metadata
Comment[de]=Ein Werkzeug, um EXIF-, IPTC- und XMP-Metadaten zu bearbeiten.
Comment[el]=Εργαλείο επεξεργασίας μεταδεδομένων EXIF, IPTC και XMP
Comment[en_GB]=A tool to edit EXIF, IPTC and XMP metadata
Comment[es]=Una herramienta para editar los metadatos EXIF, IPTC y XMP.
Comment[et]=Tööriist EXIF-i, IPTC ja XMP metaandmete muutmiseks
Comment[eu]=EXIF, IPTC eta XMP metadatuak editatzeko tresna
Comment[fi]=Exif, iptc ja xmp-metatietojen muokkaus
Comment[fr]=Outil d'édition des métadonnées « EXIF », « IPTC » et « XMP »
Comment[ga]=Uirlis lenar féidir meiteashonraí EXIF, IPTC, agus XMP a chur in eagar
Comment[gl]=Unha ferramenta para editar metadatos EXIF, IPTC e XMP
Comment[he]=כלי לעריכת מידע EXIF,‏ IPTC ו-XMP
Comment[hne]=एक्सिफ, आईपीटीसी अउ एक्सएमपी मेटाडाटा ल संपादित करे के एक औजार
Comment[hu]=Egy eszköz EXIF, IPTC és XMP metaadat szerkesztéséhez
Comment[is]=Verkfæri til að eiga við EXIF, IPTC og XMP lýsigögn
Comment[it]=Uno strumento per modificare i dati aggiuntivi EXIF, IPTC e XMP
Comment[ja]=Exif, IPTC, XMP メタデータを編集するツール
Comment[km]=ឧបករណ៍​ត្រូវ​កែសម្រួល EXIF, IPTC និង​ទិន្នន័យ​មេតា XMP
Comment[lv]=Rīks EXIF, IPTC un XMP metadatu rediģēšanai
Comment[nb]=Et verktøy for å redigere EXIF-, IPIC- og XMP-metadata
Comment[nds]=En Warktüüch, mit dat sik EXIF-, IPTC- un XMP-Metadaten bewerken laat
Comment[nl]=Een hulpmiddel voor het bewerken van EXIF-, IPTC- en XMP-metadata
Comment[pa]=EXIF, IPTC ਅਤੇ XMP ਮੇਟਾਡਾਟਾ ਸੋਧਣ ਲਈ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do edycji meta-danych EXIF, IPTC i XMP
Comment[pt]=Uma ferramenta para editar meta-dados EXIF, IPTC e XMP
Comment[pt_BR]=Uma ferramenta para editar metadados EXIF, IPTC e XMP
Comment[ro]=O unealtă de editat metadatele EXIF, IPTC și XMP
Comment[ru]=Инструмент для редактирования метаданных EXIF, IPTC и XMP
Comment[sk]=Nástroj na úpravu EXIF, IPTC a XMP metadát
Comment[sl]=Orodje za urejanja metapodatkov EXIF, IPTC in XMP
Comment[sq]=Një mjet për të modifikuar EXIF, IPTC dhe XMP metadata
Comment[sv]=Ett verktyg för att redigera EXIF-, IPTC- och XMP-metadata
Comment[th]=เครื่องมือแก้ไขข้อมูลกำกับภาพแบบ EXIF, IPTC และ XMP
Comment[tr]=EXIF, IPTC ve XMP üstverilerini düzenlemek için bir araç
Comment[uk]=Інструмент для редагування метаданих EXIF, IPTC і XMP
Comment[x-test]=xxA tool to edit EXIF, IPTC and XMP metadataxx
Comment[zh_CN]=一个编辑 EXIF、IPTC 和 XMP 元数据的工具
Comment[zh_TW]=編輯 EXIF、IPTC 和 XMP 中繼資料
Icon=kipi-metadataedit
UntranslatedGenericName=MetadataEdit
Name=MetadataEdit
Name[ast]=MetadataEdit
Name[bg]=Редактиране на метаданни
Name[bs]=MetadataEdit
Name[ca]=MetadataEdit
Name[ca@valencia]=MetadataEdit
Name[cs]=MetadataEdit
Name[da]=MetadataEdit
Name[de]=Metadaten-Editor
Name[el]=MetadataEdit
Name[en_GB]=MetadataEdit
Name[es]=Editar metadatos
Name[et]=Metaandmete redaktor
Name[eu]=Metadatuen editorea
Name[fi]=Metadata-editori
Name[fr]=Modification de méta données
Name[ga]=MetadataEdit
Name[gl]=MetadataEdit
Name[he]=עריכת Metadata
Name[hne]=मेटाडाटा-एडिट
Name[hu]=Metaadat szerkesztő
Name[is]=MetadataEdit
Name[it]=Modifica dei dati aggiuntivi
Name[ja]=MetadataEdit
Name[km]=កែសម្រួល​ទិន្នន័យ​មេតា
Name[ko]=MetadataEdit
Name[lv]=Metadatu redaktors
Name[nb]=MetadataEdit
Name[nds]=Metadaten bewerken
Name[nl]=MetadataEdit
Name[pa]=MetadataEdit
Name[pl]=EdycjaMeta-danych
Name[pt]=Editor de Meta-Dados
Name[pt_BR]=Editor de metadados
Name[ro]=Editare metadate
Name[ru]=Редактирование метаданных
Name[sk]=Úprava metadát
Name[sl]=MetadataEdit
Name[sq]=MetadataEdit
Name[sv]=Metadataeditor
Name[th]=แก้ไขข้อมูลของภาพ
Name[tr]=Metadata Düzenle
Name[uk]=MetadataEdit
Name[x-test]=xxMetadataEditxx
Name[zh_CN]=元数据编辑
Name[zh_TW]=中繼資料編輯
ServiceTypes=KIPI/Plugin
Type=Service
X-KDE-Library=kipiplugin_metadataedit
X-KIPI-PluginCategories=Image
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Gilles Caulier, caulier dot gilles at gmail dot com
